--- xcircuit.h.orig	2026-04-28 14:26:52 UTC
+++ xcircuit.h
@@ -26,7 +26,7 @@ typedef unsigned long long	u_long_long;
 
 /* In addition, caddr_t is deprecated but will just be recast here to	*/
 /* the recommended void *.						*/
-typedef void *			caddr_t;
+// typedef void *			caddr_t;
 #endif
 #endif
 
