--- echogui/testgui.c.orig	2006-02-24 19:28:15 UTC
+++ echogui/testgui.c
@@ -1,6 +1,6 @@
 /* Form definition file generated with fdesign. */
 
-#include <X11/forms.h>
+#include <forms.h>
 #include <stdlib.h>
 #include "testgui.h"
 
