--- client/mysqltest.cc.orig	2026-01-31 11:50:12.000000000 +0100
+++ client/mysqltest.cc	2026-02-08 10:42:07.309651000 +0100
@@ -35,6 +35,7 @@
 
 #define VER "3.5"
 
+#include <ctype.h>
 #include "client_priv.h"
 #include <mysql_version.h>
 #include <mysqld_error.h>
