--- include/Covar.h.orig	2024-05-27 23:23:59 UTC
+++ include/Covar.h
@@ -19,6 +19,7 @@
 #define gcta2_covar_h
 #include <vector>
 #include <string>
+#include <cstdint>
 #include <map>
 #include "Pheno.h"
 
