--- include/Surelog/DesignCompile/CompileHelper.h.orig	2025-08-30 03:55:56 UTC
+++ include/Surelog/DesignCompile/CompileHelper.h
@@ -33,6 +33,7 @@
 #include <Surelog/SourceCompile/VObjectTypes.h>
 
 #include <cstdint>
+#include <filesystem>
 #include <string>
 #include <string_view>
 #include <unordered_map>
