--- include/Marker.h.orig	2024-05-28 12:14:10 UTC
+++ include/Marker.h
@@ -20,6 +20,7 @@
 #include <vector>
 #include <map>
 #include <utility>
+#include <cstdint>
 using std::vector;
 using std::string;
 using std::to_string;
