--- include/Surelog/Design/ModuleInstance.h.orig	2025-08-30 03:55:56 UTC
+++ include/Surelog/Design/ModuleInstance.h
@@ -36,6 +36,7 @@
 #include <uhdm/module_array.h>
 
 #include <cstdint>
+#include <filesystem>
 #include <map>
 #include <set>
 #include <string>
