--- src/deps/juce/modules/juce_core/native/juce_BasicNativeHeaders.h.orig	2026-07-15 11:46:45 UTC
+++ src/deps/juce/modules/juce_core/native/juce_BasicNativeHeaders.h
@@ -242,7 +242,6 @@
  #include <sys/sysctl.h>
  #include <sys/time.h>
  #include <sys/types.h>
- #include <sys/user.h>
  #include <sys/wait.h>
  #include <utime.h>
  #include <poll.h>
