--- src/async/core/AsyncMsg.h.orig	2019-03-10 00:47:36 UTC
+++ src/async/core/AsyncMsg.h
@@ -129,7 +129,7 @@ An example of how to use the AsyncMsg class
 #include <vector>
 #include <map>
 #include <limits>
-#include <endian.h>
+#include <sys/endian.h>
 #include <stdint.h>
 
 
