Unixify built-in help.

--- Source/Console/Console.cpp.orig	2026-05-23 07:19:19 UTC
+++ Source/Console/Console.cpp
@@ -221,7 +221,7 @@ static void DisplayProperUsage(FILE * pFile)
 **************************************************************************************************/
 static void DisplayProperUsage(FILE * pFile)
 {
-    fwprintf(pFile, L"Proper Usage: [EXE] [Input File] [Output File] [Mode]\n\n");
+    fwprintf(pFile, L"Proper Usage: [mac] [Input File] [Output File] [Mode]\n\n");
 
     fwprintf(pFile, L"Modes:\n");
     fwprintf(pFile, L"    Compress (fast): '-c1000'\n");
@@ -242,18 +242,18 @@ static void DisplayProperUsage(FILE * pFile)
     fwprintf(pFile, L"    Read the entire file until the end of file if it's unknown length so the seek table can be made perfect: -readfullinput'\n\n");
 
     fwprintf(pFile, L"Examples:\n");
-    fwprintf(pFile, L"    Compress: mac.exe \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000\n");
-    fwprintf(pFile, L"    Compress: mac.exe \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000 -threads=16 -t \"Artist=Metallica|Album=Black|Name=One\"\n");
-    fwprintf(pFile, L"    Compress: mac.exe \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000 -t \"Artist=Metallica|Album=Black|Name=One\"\n");
-    fwprintf(pFile, L"    Compress: mac.exe \"Metallica - One.wav\" auto -c2000\n");
-    fwprintf(pFile, L"    Transcode from pipe: ffmpeg.exe -i \"Metallica - One.flac\" -f wav - | mac.exe - \"Metallica - One.ape\" -c2000\n");
-    fwprintf(pFile, L"    Decompress: mac.exe \"Metallica - One.ape\" \"Metallica - One.wav\" -d\n");
-    fwprintf(pFile, L"    Decompress: mac.exe \"Metallica - One.ape\" auto -d\n");
-    fwprintf(pFile, L"    Decompress: mac.exe \"Metallica - One.ape\" \"Metallica - One.wav\" -d -threads=16\n");
-    fwprintf(pFile, L"    Verify: mac.exe \"Metallica - One.ape\" -v\n");
-    fwprintf(pFile, L"    Full Verify: mac.exe \"Metallica - One.ape\" -V\n");
-    fwprintf(pFile, L"    Tag: mac.exe \"Metallica - One.ape\" -t \"Artist=Metallica|Album=Black|Name=One|Comment=\\\"This is in quotes\\\"\"\n");
-    fwprintf(pFile, L"    Remove tag: mac.exe \"Metallica - One.ape\" -r\n");
+    fwprintf(pFile, L"    Compress: mac \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000\n");
+    fwprintf(pFile, L"    Compress: mac \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000 -threads=16 -t \"Artist=Metallica|Album=Black|Name=One\"\n");
+    fwprintf(pFile, L"    Compress: mac \"Metallica - One.wav\" \"Metallica - One.ape\" -c2000 -t \"Artist=Metallica|Album=Black|Name=One\"\n");
+    fwprintf(pFile, L"    Compress: mac \"Metallica - One.wav\" auto -c2000\n");
+    fwprintf(pFile, L"    Transcode from pipe: ffmpeg -i \"Metallica - One.flac\" -f wav - | mac - \"Metallica - One.ape\" -c2000\n");
+    fwprintf(pFile, L"    Decompress: mac \"Metallica - One.ape\" \"Metallica - One.wav\" -d\n");
+    fwprintf(pFile, L"    Decompress: mac \"Metallica - One.ape\" auto -d\n");
+    fwprintf(pFile, L"    Decompress: mac \"Metallica - One.ape\" \"Metallica - One.wav\" -d -threads=16\n");
+    fwprintf(pFile, L"    Verify: mac \"Metallica - One.ape\" -v\n");
+    fwprintf(pFile, L"    Full Verify: mac \"Metallica - One.ape\" -V\n");
+    fwprintf(pFile, L"    Tag: mac \"Metallica - One.ape\" -t \"Artist=Metallica|Album=Black|Name=One|Comment=\\\"This is in quotes\\\"\"\n");
+    fwprintf(pFile, L"    Remove tag: mac \"Metallica - One.ape\" -r\n");
 }
 
 /**************************************************************************************************
