--- src/sd_module/io.cpp.orig	2019-05-24 15:26:00 UTC
+++ src/sd_module/io.cpp
@@ -13,7 +13,7 @@
 /* You should have received a copy of the GNU General Public License */
 /* along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
-#define _POSIX_C_SOURCE 1
+//#define _POSIX_C_SOURCE 1
 #include <iostream>
 #include <time.h>
 #include <string.h>
