--- src/yagi.c.orig	2005-07-09 19:59:56 UTC
+++ src/yagi.c
@@ -19,7 +19,7 @@ formulae */
 
 
 #include <stdio.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <math.h>
 #include <errno.h>
 #include "yagi.h"
