--- JuceLibraryCode/modules/juce_core/native/juce_BasicNativeHeaders.h.orig	2026-07-15 09:36:34 UTC
+++ JuceLibraryCode/modules/juce_core/native/juce_BasicNativeHeaders.h
@@ -243,7 +243,6 @@
  #include <sys/sysctl.h>
  #include <sys/time.h>
  #include <sys/types.h>
- #include <sys/user.h>
  #include <sys/wait.h>
  #include <utime.h>
  #include <poll.h>
