--- emulation/TIASnd.h.orig	2021-01-23 11:09:35 UTC
+++ emulation/TIASnd.h
@@ -20,6 +20,8 @@
 #ifndef TIASOUND_HXX
 #define TIASOUND_HXX
 
+#include <cmath>
+
 #include "bspf.h"
 
 namespace Emulation {
