--- src/qmapshack/gis/wpt/CGisItemWpt.cpp.orig	2025-07-04 12:38:57 UTC
+++ src/qmapshack/gis/wpt/CGisItemWpt.cpp
@@ -23,6 +23,7 @@
 #include <QPainterPath>
 #include <QtWidgets>
 #include <QtXml>
+#include <QPainterPath>
 
 #include "CMainWindow.h"
 #include "canvas/CCanvas.h"
